from django.db import models
from base.models import BaseModel
from settings import EMAIL_CHOICES, DB_CHOICES, PROJECT_TYPES, REGISTRAR_CHOICES



class DomainBase(BaseModel):
    url = models.CharField(max_length=512, unique=True)
    server = models.ForeignKey("Server", blank=True, null=True, max_length=128)
    email = models.CharField(max_length=64, choices=EMAIL_CHOICES, blank=True)
    path = models.CharField(max_length=255, blank=True)
    project_type = models.CharField(max_length=64, choices=PROJECT_TYPES, blank=True)
    db_type = models.CharField(max_length=64, choices=DB_CHOICES, blank=True)
    db_name = models.CharField(max_length=255, blank=True)
    is_active = models.BooleanField(default=1)
    
    class Meta:
        abstract = True
        ordering = ['url']
    
    def __unicode__(self):
        return self.url


class Domain(DomainBase):
    manage_nameserver = models.BooleanField(default=False)
    domain_registrar = models.CharField(max_length=128, choices=REGISTRAR_CHOICES)


class Subdomain(DomainBase):
    main_domain = models.ForeignKey(Domain)
    
class DomainAlias(BaseModel):
    alias = models.CharField(max_length=512)
    domain = models.ForeignKey(Domain)
    
    def __unicode__(self):
        return self.alias

class Server(BaseModel):
    hostname = models.CharField(max_length=32)
    ip_address = models.IPAddressField()
    reverse_lookup = models.CharField(max_length=255, blank=True)

    def __unicode__(self):
        return "%s" % (self.hostname,)
